==> openGion7.2.5.0_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE56S.sql <==
/****************************************************************************/
/* GE56 ( 帳票ｴﾗｰﾃｰﾌﾞﾙ )                                                    */
/*                                                                          */
/* Created : 2018/09/28 16:03:25                                            */
/****************************************************************************/

CREATE TABLE GE56 (
   SYSTEM_ID    VARCHAR ( 10 )                  NOT NULL                                                /*  10 ｼｽﾃﾑID       */
 , YKNO         INTEGER             DEFAULT 0   NOT NULL                                                /*  20 要求NO       */
 , ERRMSG       TEXT                                                                                    /*  30 ｴﾗｰﾒｯｾｰｼﾞ    */
 , UNIQSEQ      BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQSEQ)      /*  50 ｼｰｹﾝｽ番号    */
 , FGJ          VARCHAR (  1 )      DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR ( 14 )                                                                          /* 820 登録日時     */
 , PGSET        VARCHAR ( 10 )                                                                          /* 830 作成PG       */
 , PGPSET       VARCHAR ( 10 )                                                                          /* 840 作成親PG     */
 , USRSET       VARCHAR ( 10 )                                                                          /* 850 作成者       */
 , DYUPD        VARCHAR ( 14 )                                                                          /* 860 更新日時     */
 , PGUPD        VARCHAR ( 10 )                                                                          /* 870 更新PG       */
 , PGPUPD       VARCHAR ( 10 )                                                                          /* 880 更新親PG     */
 , USRUPD       VARCHAR ( 10 )                                                                          /* 890 更新者       */
);

==> openGion7.3.1.3_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE56S.sql <==
/****************************************************************************/
/* GE56 ( 帳票ｴﾗｰﾃｰﾌﾞﾙ )                                                    */
/*                                                                          */
/* Created : 2020/12/16 08:14:03                                            */
/****************************************************************************/

CREATE TABLE GE56 (
   SYSTEM_ID    VARCHAR ( 10 )                  NOT NULL                                                /*  10 ｼｽﾃﾑID       */
 , YKNO         INTEGER             DEFAULT 0   NOT NULL                                                /*  20 要求NO       */
 , ERRMSG       TEXT                                                                                    /*  30 ｴﾗｰﾒｯｾｰｼﾞ    */
 , UNIQSEQ      BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQSEQ)      /*  50 ｼｰｹﾝｽ番号    */
 , FGJ          VARCHAR (  1 )      DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR ( 14 )                                                                          /* 820 作成日時     */
 , PGSET        VARCHAR ( 10 )                                                                          /* 830 作成PG       */
 , PGPSET       VARCHAR ( 10 )                                                                          /* 840 作成親PG     */
 , USRSET       VARCHAR ( 10 )                                                                          /* 850 作成者       */
 , DYUPD        VARCHAR ( 14 )                                                                          /* 860 更新日時     */
 , PGUPD        VARCHAR ( 10 )                                                                          /* 870 更新PG       */
 , PGPUPD       VARCHAR ( 10 )                                                                          /* 880 更新親PG     */
 , USRUPD       VARCHAR ( 10 )                                                                          /* 890 更新者       */
);
